
!***********************************************************************
!   Portions of Models-3/CMAQ software were developed or based on      *
!   information from various groups: Federal Government employees,     *
!   contractors working on a United States Government contract, and    *
!   non-Federal sources (including research institutions).  These      *
!   research institutions have given the Government permission to      *
!   use, prepare derivative works, and distribute copies of their      *
!   work in Models-3/CMAQ to the public and to permit others to do     *
!   so.  EPA therefore grants similar permissions for use of the       *
!   Models-3/CMAQ software, but users are requested to provide copies  *
!   of derivative works to the Government without restrictions as to   *
!   use by others.  Users are responsible for acquiring their own      *
!   copies of commercial software associated with Models-3/CMAQ and    *
!   for complying with vendor requirements.  Software copyrights by    *
!   the MCNC Environmental Modeling Center are used with their         *
!   permissions subject to the above restrictions.                     *
!***********************************************************************

! RCS file, release, date & time of last delta, author, state, [and locker]
! $Header: /project/work/rep/MCIP2/src/mcip2/dealloc_ctm.F,v 1.5 2004/08/30 16:51:26 tlotte Exp $ 


SUBROUTINE dealloc_ctm

!-------------------------------------------------------------------------------
! Name:     Deallocate Arrays for CTM Dimensions
! Purpose:  Deallocate arrays based on CTM grid.
! Revised:  14 Sep 2001  Original version.  (T. Otte)
!           27 Feb 2002  Renamed SURF2 as WIND10.  Removed RIB.  (T. Otte)
!           18 Mar 2003  Removed JDRATE.  (T. Otte)
!           09 Jun 2003  Added SNOCOV to METCRO2D.  (D. Schwede)
!                        Removed extraneous variables from output.  (T. Otte)
!           09 Aug 2004  Added JACOBS, WSPD10, WDIR10, SOIM1, SOIM2, SOIT1,
!                        SOIT2, SLTYP, JACOBF, QG, TEMP2, and LAI.  Restored
!                        GRIDBDY2D file to output.  Modified code so that arrays
!                        are made available in output only if user options in
!                        MM5 generate those data.  (T. Otte and D. Schwede)
!           01 Dec 2004  Added PURB.  (T. Otte)
!           25 Feb 2005  Eliminated GRIDCRO3D for hydrostatic runs.  (T. Otte)
!           19 Aug 2005  Moved VD_C from a pointer to MC2 to an individual
!                        array that is deallocated in DEALLOC_DEPV.  (T. Otte)
!-------------------------------------------------------------------------------

  USE coord
  USE vgrd
  USE groutcom
  USE mcoutcom
  USE mdoutcom

  IMPLICIT NONE

!-------------------------------------------------------------------------------
! Deallocate grid arrays for COORD.
!-------------------------------------------------------------------------------

  DEALLOCATE ( vglvs_gd   )
  DEALLOCATE ( x3face_gd  )

!-------------------------------------------------------------------------------
! Deallocate grid arrays for VGRD.
!-------------------------------------------------------------------------------

  DEALLOCATE ( x3face     )
  DEALLOCATE ( x3midl     )

!-------------------------------------------------------------------------------
! Release memory for GROUTCOM arrays.
!-------------------------------------------------------------------------------

  NULLIFY    ( glat_d     )
  NULLIFY    ( glon_d     ) 
  NULLIFY    ( gmsfsq_d   )
  DEALLOCATE ( gd2        )

  NULLIFY    ( glat_c     )
  NULLIFY    ( glon_c     )
  NULLIFY    ( gmsfsq_c   )
  NULLIFY    ( gtopo_c    )
  NULLIFY    ( gdluse_c   )
  IF ( ASSOCIATED ( gpurb_c ) )  NULLIFY    ( gpurb_c    )
  DEALLOCATE ( gc2        )

  NULLIFY    ( glat_b     )
  NULLIFY    ( glon_b     )
  NULLIFY    ( gmsfsq_b   )
  NULLIFY    ( gtopo_b    )
  NULLIFY    ( gdluse_b   )
  IF ( ASSOCIATED ( gpurb_b ) )  NULLIFY    ( gpurb_b    )
  DEALLOCATE ( gb2        )

  IF ( ASSOCIATED ( gx3htf_c ) ) NULLIFY    ( gx3htf_c   )
  IF ( ASSOCIATED ( gx3htm_c ) ) NULLIFY    ( gx3htm_c   )
  IF ( ALLOCATED  ( gc3      ) ) DEALLOCATE ( gc3        )

!-------------------------------------------------------------------------------
! Release memory for MCOUTCOM arrays, except dry deposition species.
!-------------------------------------------------------------------------------

  NULLIFY    ( prsfc_c    )
  NULLIFY    ( jacobs_c   )
  NULLIFY    ( ustar_c    )
  NULLIFY    ( wstar_c    )
  NULLIFY    ( pbl_c      )
  NULLIFY    ( zzero_c    )
  NULLIFY    ( moli_c     )
  NULLIFY    ( hfx_c      )
  NULLIFY    ( qfx_c      )
  NULLIFY    ( radyni_c   )
  NULLIFY    ( rbndyi_c   )
  NULLIFY    ( rstomi_c   )
  NULLIFY    ( tempg_c    )
  NULLIFY    ( temp10_c   )
  NULLIFY    ( tem1p5_c   )
  NULLIFY    ( wspd10_c   )
  NULLIFY    ( wdir10_c   )
  NULLIFY    ( glw_c      )
  NULLIFY    ( gsw_c      )
  NULLIFY    ( rgrnd_c    )
  NULLIFY    ( rainn_c    )
  NULLIFY    ( rainc_c    )
  NULLIFY    ( cfract_c   )
  NULLIFY    ( cldtop_c   )
  NULLIFY    ( cldbot_c   )
  NULLIFY    ( wbar_c     )
  NULLIFY    ( snocov_c   )
  DEALLOCATE ( mc2        )

  IF ( ALLOCATED  ( temp2_c   ) ) DEALLOCATE ( temp2_c    )

  IF ( ASSOCIATED ( soim1_c   ) ) NULLIFY    ( soim1_c    )
  IF ( ASSOCIATED ( soim2_c   ) ) NULLIFY    ( soim2_c    )
  IF ( ASSOCIATED ( soit1_c   ) ) NULLIFY    ( soit1_c    )
  IF ( ASSOCIATED ( soit2_c   ) ) NULLIFY    ( soit2_c    )
  IF ( ASSOCIATED ( sltyp_c   ) ) NULLIFY    ( sltyp_c    )
  IF ( ASSOCIATED ( lai_c     ) ) NULLIFY    ( lai_c      )
  IF ( ALLOCATED  ( pc2       ) ) DEALLOCATE ( pc2        )

  NULLIFY    ( jacobf_c   )
  NULLIFY    ( jacobm_c   )
  NULLIFY    ( densa_j_c  )
  NULLIFY    ( what_jd_c  )
  NULLIFY    ( tempa_c    )
  NULLIFY    ( wvapor_c   )
  NULLIFY    ( press_c    )
  NULLIFY    ( densa_c    )
  NULLIFY    ( wwind_c    )
  NULLIFY    ( x3htm_c    )
  NULLIFY    ( x3htf_c    )
  DEALLOCATE ( mc3        )

  NULLIFY    ( jacobf_b   )
  NULLIFY    ( jacobm_b   )
  NULLIFY    ( densa_j_b  )
  NULLIFY    ( what_jd_b  )
  NULLIFY    ( tempa_b    )
  NULLIFY    ( wvapor_b   )
  NULLIFY    ( press_b    )
  NULLIFY    ( densa_b    )
  NULLIFY    ( wwind_b    )
  NULLIFY    ( x3htm_b    )
  NULLIFY    ( x3htf_b    )
  DEALLOCATE ( mb3        )

  IF ( ASSOCIATED ( cldwtr_c ) ) NULLIFY    ( cldwtr_c   )
  IF ( ASSOCIATED ( ranwtr_c ) ) NULLIFY    ( ranwtr_c   )
  IF ( ASSOCIATED ( qice_c   ) ) NULLIFY    ( qice_c     )
  IF ( ASSOCIATED ( qsnow_c  ) ) NULLIFY    ( qsnow_c    )
  IF ( ASSOCIATED ( qgraup_c ) ) NULLIFY    ( qgraup_c   )
  IF ( ALLOCATED  ( qc3      ) ) DEALLOCATE ( qc3        )

  IF ( ASSOCIATED ( cldwtr_b ) ) NULLIFY    ( cldwtr_b   )
  IF ( ASSOCIATED ( ranwtr_b ) ) NULLIFY    ( ranwtr_b   )
  IF ( ASSOCIATED ( qice_b   ) ) NULLIFY    ( qice_b     )
  IF ( ASSOCIATED ( qsnow_b  ) ) NULLIFY    ( qsnow_b    )
  IF ( ASSOCIATED ( qgraup_b ) ) NULLIFY    ( qgraup_b   )
  IF ( ALLOCATED  ( qb3      ) ) DEALLOCATE ( qb3        )

!-------------------------------------------------------------------------------
! Release memory for MDOUTCOM arrays.
!-------------------------------------------------------------------------------

  NULLIFY    ( uu_d       )
  NULLIFY    ( vv_d       )
  NULLIFY    ( uhat_s     )
  NULLIFY    ( vhat_t     )
  DEALLOCATE ( md3        )

END SUBROUTINE dealloc_ctm
